# Original version of the VFG schema

This is the original version used for the June 20th 2024 Genius.Core demo.

[VFG 0.1.0](../0_1_0/) is the first version adopted for the new Genius codebase. Retroactive set of changes (what's different about this VS 0.1.0):

- `cpd` Boolean is used in place of the `distribution` enum
    - Reason this was later changed: the enum is more extensible and captures the same information
- no `version` field
- `learnable` field, which is specific to Genius.Core, is included
    - Reason this was later removed: this is a system setting the user might want to keep track of, but is not part of the minimum viable description of a factor graph (it is extrinsic)
    